dune_core::cfg

Struct Pinned

pub struct Pinned {
    pub cmd: String,
    pub environ: Option<HashMap<String, String>>,
    pub down: Option<String>,
    pub pre_down: Option<Vec<String>>,
    /* private fields */
}
Pinned process informations.

Fields

cmd: String

Command representing the Pinned process.

environ: Option<HashMap<String, String>>

Environment variables required to launch the process.

down: Option<String>

Instruction required to properly shutdown the process.

pre_down: Option<Vec<String>>

Set of instructions launched before properly shutting down the process.

Implementations

Source

impl Pinned

pub fn cores(&mut self) -> Cores

Lazyly collect cores list required for the current process.

pub fn n_cores(&mut self) -> usize

Lazyly get the number of cores required for the current process.